#: -*- coding: utf-8 -*-
"""
Settings
========
Default required settings. You can override them in your project settings
file.
"""

# Allowed layout pack
CRISPY_ALLOWED_TEMPLATE_PACKS = (
    'bootstrap',
    'uni_form',
    'bootstrap3',
    'bootstrap4',
    'bulma',
)

CRISPY_TEMPLATE_PACK = 'bulma'